#!/usr/bin/env python3

#
#   make multiple versions of whisper STT and use mpvsubs.py to play
#
###from fire import Fire
import click
from faster_whisper import WhisperModel
import time
import pysubs2
import os
# importing module
import logging
import datetime as dt
import sys
from console import fg, bg
import autocorrect
#from autocorrect import Speller

#
#from silero_vad import load_silero_vad, read_audio, get_speech_timestamps
#https://github.com/snakers4/silero-vad/wiki/Examples-and-Dependencies#examples
#
#
# Create and configure logger
LOGFILE = os.path.expanduser("~/fwhisp.log")
logging.basicConfig(filename=LOGFILE,
                    format='%(asctime)s %(message)s',
                    filemode='a')
# Creating an object
logger = logging.getLogger()
# Setting the threshold of logger to DEBUG
logger.setLevel(logging.INFO)

"""
https://github.com/SYSTRAN/faster-whisper



2024-08-26 20:09:48,943 Openning FILE speechtest.mp3 with MODEL  tiny.en
2024-08-26 20:09:49,432 Starting FILE speechtest.mp3 with MODEL  tiny.en
2024-08-26 20:09:49,552 Processing audio with duration 01:15.352
2024-08-26 20:09:51,455 Finished FILE speechtest.mp3 with MODEL tiny.en after 0:00:02.022508

2024-08-26 20:09:52,636 Openning FILE speechtest.mp3 with MODEL  base.en
2024-08-26 20:09:53,541 Starting FILE speechtest.mp3 with MODEL  base.en
2024-08-26 20:09:53,657 Processing audio with duration 01:15.352
2024-08-26 20:09:56,501 Finished FILE speechtest.mp3 with MODEL base.en after 0:00:02.959267

2024-08-26 20:09:57,676 Openning FILE speechtest.mp3 with MODEL  small.en
2024-08-26 20:09:58,371 Starting FILE speechtest.mp3 with MODEL  small.en
2024-08-26 20:09:58,489 Processing audio with duration 01:15.352
2024-08-26 20:10:06,467 Finished FILE speechtest.mp3 with MODEL small.en after 0:00:08.095602

2024-08-26 20:10:07,686 Openning FILE speechtest.mp3 with MODEL  medium.en
2024-08-26 20:10:09,583 Starting FILE speechtest.mp3 with MODEL  medium.en
2024-08-26 20:10:09,699 Processing audio with duration 01:15.352
2024-08-26 20:10:31,897 Finished FILE speechtest.mp3 with MODEL medium.en after 0:00:22.314353

2024-08-26 20:10:33,128 Openning FILE speechtest.mp3 with MODEL  distil-medium.en MISSING 45 sec
2024-08-26 20:10:34,222 Starting FILE speechtest.mp3 with MODEL  distil-medium.en
2024-08-26 20:10:34,338 Processing audio with duration 01:15.352
2024-08-26 20:10:43,387 Finished FILE speechtest.mp3 with MODEL distil-medium.en after 0:00:09.164615
"""

@click.command()
@click.argument('infile')
@click.option('--model_size', "-m", default=None, help='Optional model size like tiny.en small base _medium_')
@click.option('--language', "-l", default=None, help='Optionaly force language like cs')
@click.option('--outputname', "-o", default=None, help='Optionaly overwrite output filename')
def main( infile, model_size, language, outputname):
    """
    STT for video by whisper. Give me Video-file and model-name (tiny,base...); saves with modelsize in filename; good to test models
    """
    if model_size is None:
        print( """  --models_size OR  -m
        tiny.en, tiny, base.en, base,
        small.en, small,
        medium.en, medium,
        large-v1, large-v2, large-v3,
        distil-large-v2, distil-medium.en, distil-small.en, distil-large-v3
        """)
        sys.exit(1)


    # model_size = "tiny.en" # 0.075 G
    # model_size = "base.en" # 0.144 G
    # model_size = "small.en" # 0.484 G
    # model_size = "distil-medium.en" # 0.789 G
    # model_size = "medium.en" # 1.53 G
    # model_size = "large-v3"  # 3G
    # model_size = "distil-large-v3"  # 3G


    # Run on GPU with FP16
    #model = WhisperModel(model_size, device="cuda", compute_type="float16")
    # or run on GPU with INT8
    # model = WhisperModel(model_size, device="cuda", compute_type="int8_float16")

    # or run on CPU with INT8


    ##wav = read_audio( infile) # backend (sox, soundfile, or ffmpeg) required!
    ##speech_timestamps = get_speech_timestamps(wav, model)

    print(f"**** INPUT:  {infile}  /  OUTPUT:  {outputname}")
    if not os.path.exists(infile):
        print("X... file doesnt exist")
        sys.exit(1)
    print(f"******opennin****** MODEL = {model_size} *********************** logfile ", LOGFILE)
    logger.info(f"Openning FILE {infile} with MODEL  {model_size}")
    model = WhisperModel(model_size, device="cpu", compute_type="int8" ) # fp32 cpu_threads=16, num_workers=16

    timetag = dt.datetime.now()
    logger.info(f"Starting FILE {infile} with MODEL  {model_size} ")


    # *********************** TRANSCRIBE HERE *****************************
    print("*********** starting transcribe ******** ")
    if language is None:
        segments, info = model.transcribe(infile, beam_size=5)
    else:
        print(f"*****forcing******* LANGUAGE  = {language} *********************")
        segments, info = model.transcribe(infile, beam_size=5, language=language)

    print("Detected language '%s' with probability %f" % (info.language, info.language_probability))

    LANG = info.language
    if LANG in ["cs", "en"]:
        print("************  initializing autocorrect *********")
        spell = autocorrect.Speller( LANG)  # I can tune if english or so...


    results= []

    # ***************************** OUTPUTS ********************
    print("****************** going through  segments *********** ")
    for segment in segments:
        SEG_s, SEG_e, SEG_t = segment.start, segment.end, segment.text

        if LANG in ["cs", "en"]:
            SEG_t2 = spell(SEG_t)
            if SEG_t2 != SEG_t:
                print(fg.darkslategray, f"[{SEG_s:.2f}s -> {SEG_e:.2f}s] {SEG_t2} ", fg.default)
            SEG_t = SEG_t2

        print(f"[{SEG_s:.2f}s -> {SEG_e:.2f}s] {SEG_t} ")
        # srt
        segment_dict = {'start':SEG_s,'end':SEG_e,'text':SEG_t}
        results.append(segment_dict)

    logger.info(f"Finished FILE {infile} with MODEL {model_size} after {dt.datetime.now()-timetag}")

    subs = pysubs2.load_from_whisper(results)
    #save srt file

    # ================================ OUTPUT ====================
    file_name = "x.srt"
    print("> fi", infile)
    print("> di", os.path.dirname(infile))
    print("> st", os.path.splitext(os.path.dirname(infile)))
    print("> 00", os.path.splitext(os.path.dirname(infile))[0])
    print("> --" )
    dirname = ""
    if len(os.path.dirname(infile)) > 2:
        dirname = os.path.splitext(os.path.dirname(infile))[0]
        dirname = f"{dirname}/"
    else:
        dirname = ""
    print("> dn", dirname)

    if outputname is not None:
        if outputname.find(r".srt") > 0:
            file_name = f"{dirname}{outputname}"
        else:
            file_name = f"{dirname}{outputname}.srt"
    else:
        file_name = os.path.splitext(os.path.basename(infile))[0] + f"_{model_size}.srt"
        file_name = f"{dirname}{file_name}"

    #file_name = os.path.splitext(os.path.basename(infile))[0] + f".srt"
    print("i... saving: ", fg.green, file_name, fg.default)
    subs.save( file_name )
    # #save ass file
    # subs.save(file_name+'.ass')

if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""
Whatever number on system will be displayed in a graph:
 get_temp()
 get_lamax() #hcitool
 get_mem()
get_dbm() # control panel in router with selenium
"""
#import plotext.plot as plx
import matplotlib
matplotlib.use('module://drawilleplot')
#matplotlib.use('module://matplotlib-sixel')
import matplotlib.pyplot as plt
import numpy as np
import subprocess as sp
import time
import os

from fire import Fire

import datetime as dt

def move (y, x):
    print("\033[%d;%dH" % (y, x))




def graph_update(tlis,ymin=50,ymax=105, label="label", show=True):
    #os.system("clear")

    if type(tlis) == dict:
        x = tlis['x']
        y = tlis['y']
    else:
        x=range(len(tlis))
        y=tlis

    #print('x:',x)
    #print('y:',y)


    # DOESNT WORK
    #fig = plt.figure(figsize=(5, 2))
    plt.plot( x,y , '.' , label=label)
    plt.ylim(top=ymax) #ymax is your value
    plt.ylim(bottom=ymin) #ymin is your value
    plt.legend()
    #print("\033c", end="")
    #os.system('cls' if os.name == 'nt' else 'clear')
    if show:
        plt.show()
        plt.clf()
        time.sleep(1)
    #print(chr(27) + "[2J")









def get_temp():
    res=sp.check_output('cat /sys/class/thermal/thermal_zone2/temp'.split()).decode('utf8')
    res=sp.check_output('cat /sys/class/thermal/thermal_zone0/temp'.split()).decode('utf8')
    res=int(res)/1000
    return res

def get_lamax():
    res=sp.check_output('hcitool lq 4F:BE:4C:63:9E:7C'.split()).decode('utf8').strip()
    #print(res)
    res=res.split(":")[-1].strip()
    #print("/{}/".format(res))
    res=int(res)
    return res


def get_mem():
    res=sp.check_output('cat /proc/meminfo'.split()).decode('utf8').strip()
    res = res.split("\n")
    tot = [x for x in res if x.find("MemTotal")>=0 ]
    ava = [x for x in res if x.find("MemAvailable")>=0 ]
    res = [x for x in res if x.find("MemFree")>=0 ]
    #print(res)
    res=res[0].split()[1].strip()
    tot=tot[0].split()[1].strip()
    ava=ava[0].split()[1].strip()
    #print(f"/{res}/")
    res=int(res)/1000000
    tot=int(tot)/1000000
    ava=int(ava)/1000000
    return tot,ava,res






def mem():
    tlis=[]
    tlis2=[]
    maxx=60*3

    maxy=1000
    miny=1000
    os.system("clear")
    while 1==1:
        tot,ava,res=get_mem()
        #if res>maxy: maxy=res
        #if res<miny: miny=res
        #res=get_lamax()
        tlis.append(res)
        tlis2.append(ava)

        if len(tlis)>maxx:
            tlis=tlis[1:]
            tlis2=tlis2[1:]
        if len(tlis)<4:
            continue
        move(1,1)
        graph_update(tlis2,0,tot,"MEMA",show=False)
        graph_update(tlis,0,tot,"MEMF")

    return res









#=====================================webscrape DLINK

"""
  pip install selenium
  pip install webdriver_manager
"""
def get_dbm():
    print("consider workon dlink ")
    print("consider workon dlink ")
    print("consider workon dlink \n\n\n")
    from bs4 import BeautifulSoup as bs
    import time
    from selenium import webdriver
    from webdriver_manager.chrome import ChromeDriverManager

    webpage = r'https://192.168.0.1/controlPanel.html'
    ########################### ALL DRIVER HERE ######################
    #=========== it started to make errors with 83.
    options = webdriver.ChromeOptions()

    options.add_argument('--headless') # NO VISIBLE BROWSER WINDOW

    options.add_argument('--disable-infobars')
    options.add_argument('--disable-dev-shm-usage')
    options.add_argument('--no-sandbox')
    options.add_argument('--remote-debugging-port=9222')
    #ignore INVALID CERTIFICATE
    options.add_argument('--ignore-certificate-errors')
    #ChromeDriverManager().clearPreferences()
    #ChromeDriverManager().setup()
    #driver = webdriver.Chrome(ChromeDriverManager().install())
    try:
        driver = webdriver.Chrome(ChromeDriverManager().install(), options=options)
    except:
        print("X... there was an exception in installing ChromDrive...maybe ok")
        driver = webdriver.Chrome(options=options)
        #driver = webdriver.Chrome()
        #


    driver.maximize_window()

    driver.get( webpage )
    #time.sleep(1)

    txt = driver.page_source
    #print(txt)
    #print("################################################# GOT COUNTRIES")


    username = driver.find_element('xpath', '//*[@id ="tf1_usrName"]')
    password = driver.find_element('xpath', '//*[@id ="tf1_password"]')

    #print(username)
    #print(password)

    username.send_keys("admin")
    password.send_keys("")


    #driver.find_element("name","btSave").click()
    driver.find_element("xpath",'//*[@id ="btSave"]').click()


    driver.get(webpage)
    #time.sleep(2.5)

    #print("searching operator")
    operator = driver.find_element("xpath",'//*[@id ="tf1_tmpl_cpinternetinfo"]')
    #print(operator)
    opt = operator.text.split()
    dec = [ float(x.split("dBm")[0]) for x in opt if x.find("dBm")>0 ][0]
    #print(opt)
    #print( dec)
    res = dec
    return res


def dbm():

    #pip install selenium
    #pip install webdriver_manager


    tlisx=[]
    tlisy=[]
    maxx=60*3
    start = dt.datetime.now()

    os.system("clear")
    while 1==1:
        #res=get_temp()
        res=get_dbm()
        #res = -89

        tlisx.append( (dt.datetime.now() - start).total_seconds() )
        tlisy.append(res)

        if len(tlisx)>maxx:
            tlisx=tlisx[1:]
        if len(tlisy)>maxx:
            tlisy=tlisy[1:]
        if len(tlisx)<4:
            continue
        tlis = { 'x':tlisx, 'y':tlisy }
        #print(tlis)
        graph_update(tlis,-130,0,"signal")



def temp():
    tlis=[]
    maxx=60*3

    os.system("clear")
    while 1==1:
        res=get_temp()
        #res=get_lamax()
        tlis.append(res)

        if len(tlis)>maxx:
            tlis=tlis[1:]
        if len(tlis)<4:
            continue
        graph_update(tlis,40,105,"CPU temp")



def lamax():
    tlis=[]
    maxx=60*3

    os.system("clear")
    while 1==1:
        #res=get_temp()
        res=get_lamax()
        tlis.append(res)

        if len(tlis)>maxx:
            tlis=tlis[1:]
        if len(tlis)<4:
            continue
        graph_update(tlis,0,405,"LAMAX")

if __name__ == "__main__":
    Fire( {"temp":temp,
           "mem":mem,
           "dbm":dbm,
           "lamax":lamax} )



import subprocess as sp

def main():
    print("Hello from verify!")

    ok = True

    CMD = ['/usr/bin/which','uconv']
    result = sp.run( CMD, capture_output=True, text=True )
    if result.returncode != 0:
        print("!... uconv not found... apt install icu-devtools")
        ok = False
    else:
        print("i... uconv found")


    CMD = ['/usr/bin/which','iwlist']
    result = sp.run( CMD, capture_output=True, text=True )
    if result.returncode != 0:
        print("!... iwlist not found... apt install ")
        ok = False
    else:
        print("i... iwlist found")


    CMD = ['/usr/bin/which','nmcli']
    result = sp.run( CMD, capture_output=True, text=True )
    if result.returncode != 0:
        print("!... nmcli not found... apt install ")
        ok = False
    else:
        print("i... nmcli found")

    #print()


if __name__ == "__main__":
    main()
